'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
var fetch = require('node-fetch');

var shouldSet = exports.shouldSet = function shouldSet(tool) {
  return process.argv.indexOf(tool) > -1;
};

var getStatus = exports.getStatus = function getStatus(_ref) {
  var RUN_KIT_URL = _ref.RUN_KIT_URL,
      TRAVIS_EVENT_TYPE = _ref.TRAVIS_EVENT_TYPE,
      TRAVIS_REPO_SLUG = _ref.TRAVIS_REPO_SLUG,
      TRAVIS_JOB_ID = _ref.TRAVIS_JOB_ID;

  var sha = getCommitSha(TRAVIS_EVENT_TYPE);
  var repoSlug = TRAVIS_REPO_SLUG;
  var target_url = 'https://travis-ci.org/' + repoSlug + '/jobs/' + TRAVIS_JOB_ID;
  var parsedSlug = repoSlug.split('/');
  var owner = parsedSlug[0];
  var repo = parsedSlug[1];
  var runKitUrl = RUN_KIT_URL || 'https://github-status-reporter-4-travis-w97e064wfjok.runkit.sh/';

  return {
    sha: sha,
    target_url: target_url,
    owner: owner,
    repo: repo,
    runKitUrl: runKitUrl
  };
};

var getCommitSha = function getCommitSha(eventType) {
  if (eventType === 'push') {
    return process.env.TRAVIS_COMMIT;
  } else if (eventType === 'pull_request') {
    var travisCommitRange = process.env.TRAVIS_COMMIT_RANGE;
    var parsed = travisCommitRange.split('...');

    return parsed.length === 1 ? travisCommitRange : parsed[1];
  }

  console.error("event type '%s' not supported", eventType);
  return null;
};

var setStatus = exports.setStatus = function setStatus(status, context, description, success) {
  var runKitUrl = status.runKitUrl;

  var params = {
    sha: status.sha,
    target_url: status.target_url,
    owner: status.owner,
    repo: status.repo,
    context: context,
    description: description,
    state: success ? 'success' : 'failure'
  };

  fetch(runKitUrl, {
    method: 'post',
    headers: {
      Accept: 'application/json',
      'Content-Type': 'application/json'
    },

    body: JSON.stringify(params)
  }).then(function (res) {
    return res.json();
  }).then(function (res) {
    var err = !res.success;
    var message = res.message;
    // colored logging
    context = (context + ':').blue;
    description = description[success ? 'green' : 'red'];

    var log = context + ' ' + description;
    console.log(log);

    if (err) {
      console.error(context + ': Error creating status', message);
    }
  }).catch(function (err) {
    if (err) {
      console.error(context + ': Error creating status (catch)', err.message);
    }
  });

  if (!success) {
    process.exitCode = 1;
  }
};